@@ -64,7 +64,7 @@ struct Parse_Options_s
 	char * test;           /* comma-sparated features to test "" */
 	bool use_sat_solver;   /* Use the Boolean SAT based parser */
 	bool use_viterbi;      /* Use the Viterbi decoder-based parser */
-	int linkage_limit;     /* The maximum number of linkages processed 100 */
+	size_t linkage_limit;     /* The maximum number of linkages processed 100 */
 	double disjunct_cost;  /* Max disjunct cost to allow */
 	int min_null_count;    /* The minimum number of null links to allow */
 	int max_null_count;    /* The maximum number of null links to allow */
@@ -73,9 +73,9 @@ struct Parse_Options_s
 	bool islands_ok;       /* If TRUE, then linkages with islands
 	                          (separate component of the link graph)
 	                          will be generated (default=FALSE) */
-	int twopass_length;    /* min length for two-pass post processing */
-	int max_sentence_length;
-	int short_length;      /* Links that are limited in length can be
+	size_t twopass_length; /* min length for two-pass post processing */
+	size_t max_sentence_length;
+	size_t short_length;   /* Links that are limited in length can be
 	                        * no longer than this.  Default = 6 */
 	bool all_short;        /* If true, there can be no connectors that are exempt */
 	bool use_spell_guess;  /* Perform spell-guessing of unknown words. */ 
@@ -206,9 +206,11 @@ struct And_data_s
 
 struct Link_s
 {
-	short l, r;
-	Connector * lc, * rc;
-	const char * name;				  /* spelling of full link name */
+	size_t lw;              /* Offset into Linkage->word NOT Sentence->word */
+	size_t rw;              /* Offset into Linkage->word NOT Sentence->word */
+	Connector * lc;
+	Connector * rc;
+	const char * link_name; /* Spelling of full link name */
 };
 
 struct Parse_info_struct
@@ -240,24 +242,24 @@ struct Sentence_s
 {
 	Dictionary  dict;           /* words are defined from this dictionary */
 	const char *orig_sentence;  /* Copy of original sentence */
-	int    length;              /* number of words */
+	size_t length;              /* number of words */
 	Word  *word;                /* array of words after tokenization */
 	String_set *   string_set;  /* used for word names, not connectors */
 
 	/* Parse results */
 	int    num_linkages_found;  /* total number before postprocessing.  This
 	                               is returned by the count() function */
-	int    num_linkages_alloced;/* total number of linkages allocated.
+	size_t num_linkages_alloced;/* total number of linkages allocated.
 	                               the number post-processed might be fewer
 	                               because some are non-canonical */
-	int    num_linkages_post_processed;
+	size_t num_linkages_post_processed;
 	                            /* The number of linkages that are actually
 	                               put into the array that was alloced.
 	                               This is not the same as num alloced
 	                               because some may be non-canonical. */
-	int    num_valid_linkages;  /* number with no pp violations */
+	size_t num_valid_linkages;  /* number with no pp violations */
 	bool   null_links;          /* null links allowed */
-	int    null_count;          /* number of null links in linkages */
+	size_t null_count;          /* number of null links in linkages */
 	Parse_info     parse_info;  /* set of parses for the sentence */
 	Linkage_info * link_info;   /* array of valid and invalid linkages (sorted) */
 
@@ -310,8 +312,8 @@ struct Domain_s
 	List_o_links * lol;
 	DTreeLeaf *    child;
 	Domain *       parent;
-	int            size;
-	int            start_link;  /* the link that started this domain */
+	size_t         size;
+	size_t         start_link;  /* the link that started this domain */
 	char           type;        /* one letter name */
 };
 
@@ -325,16 +327,16 @@ struct DTreeLeaf_s
 
 struct PP_data_s
 {
-	int N_domains;
+	size_t N_domains;
 	List_o_links * word_links[MAX_SENTENCE];
 	List_o_links * links_to_ignore;
 	Domain domain_array[MAX_LINKS]; /* the domains, sorted by size */
-	int length;                     /* length of current sentence */
+	size_t length;                  /* length of current sentence */
 };
 
 struct PP_info_s
 {
-	int       num_domains;
+	size_t          num_domains;
 	const char **   domain_name;
 };
 
@@ -349,7 +351,7 @@ struct Postprocessor_s
 	int *relevant_contains_none_rules;
 	/* the following maintain state during a call to post_process() */
 	String_set *sentence_link_name_set;        /* link names seen for sentence */
-	int visited[MAX_SENTENCE];                   /* for the depth-first search */
+	bool visited[MAX_SENTENCE];                 /* for the depth-first search */
 	PP_node *pp_node;
 	PP_data pp_data;
 };
@@ -370,7 +372,7 @@ struct Postprocessor_s
  */
 struct Sublinkage_s
 {
-	int       num_links;          /* Number of links in array */
+	size_t    num_links;          /* Number of links in array */
 	Link **   link;               /* Array of links */
 	PP_info * pp_info;            /* PP info for each link */
 	const char * violation;       /* Name of violation, if any */
@@ -379,13 +381,13 @@ struct Sublinkage_s
 
 struct Linkage_s
 {
-	int             num_words;  /* number of (tokenized) words */
+	size_t          num_words;  /* number of (tokenized) words */
 	const char *  * word;       /* array of word spellings */
 	Linkage_info*   info;       /* index and cost information */
 #ifdef USE_FAT_LINKAGES
 	Sublinkage *    sublinkage; /* A parse with conjunctions will have several */
 #else
-	Sublinkage      sublinkage; /* A parse with conjunctions will have several */
+	Sublinkage      sublinkage; /* Just one */
 #endif /* USE_FAT_LINKAGES */
 
 	Sentence        sent;
@@ -394,7 +396,7 @@ struct Linkage_s
 #ifdef USE_FAT_LINKAGES
 	int             num_sublinkages; /* One for thin linkages, bigger for fat */
 	int             current;    /* Allows user to select particular sublinkage */
-	int             unionized;  /* if TRUE, union of links has been computed */
+	bool            unionized;  /* if TRUE, union of links has been computed */
 	DIS_node      * dis_con_tree; /* Disjunction-conjunction tree */
 #endif /* USE_FAT_LINKAGES */
 
