@@ -1,20 +1,22 @@
 /*************************************************************************/
 /* Copyright (c) 2005  Sampo Pyysalo                                     */
+/* Copyright (c) 2009 Linas Vepstas                                      */
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the link grammar parsing system is subject to the terms of the */
-/* license set forth in the LICENSE file included with this software,    */
-/* and also available at http://www.link.cs.cmu.edu/link/license.html    */
+/* license set forth in the LICENSE file included with this software.    */
 /* This license allows free redistribution and use in source and binary  */
 /* forms, with or without modification, subject to certain conditions.   */
 /*                                                                       */
 /*************************************************************************/
 
-#include <sys/types.h>
+/* On MS Windows, regex.h fails to pull in size_t, so work around this by
+ * including <stddef.h> before <regex.h> (<sys/types.h> is not enough) */
+#include <stddef.h>
 #include <regex.h>
 #include "api-structures.h"
+#include "dict-api.h"
 #include "link-includes.h"
-#include "read-dict.h"
 #include "regex-morph.h"
 #include "structures.h"
 
@@ -115,6 +117,9 @@ void free_regexs(Dictionary dict)
 	{
 		Regex_node *next = re->next;
 		regfree((regex_t *)re->re);
+		free(re->re);
+		free(re->name);
+		free(re->pattern);
 		free(re);
 		re = next;
 	}
